// node modules
import React from "react";
import { Meta, Story } from "@storybook/react";

// local components
import { Input, InputProps } from "../components/input";
import { ValidatedInput, ValidatedInputProps } from "../components/validated_input";
import { Typography } from "../components/typography";

export default {
    title: 'Example/Inputs',
} as Meta;

const InputTpl: Story<InputProps> = (args) => <Input {...args} />;

export const input = InputTpl.bind({});

input.args = {
    label: 'Input label',
    disabled: false,
    type: 'text',
    error: false,
    closeIcon: true,
    adornmentStart: '',
    adornmentEnd: 'km'
}

const ValidatedInputTpl: Story<ValidatedInputProps> = (args) => {
    return (
        <div>
            <ValidatedInput
                label="Max length 10 symbols"
                validationQuery={{
                    maxLength: {
                        value: 10,
                        errorMessage: 'Max length 10 symbols'
                    }
                }}
                {...args}
            />
            <br/>
            <ValidatedInput
                label="Min length 5 symbols"
                validationQuery={{
                    minLength: {
                        value: 5,
                        errorMessage: 'Min length 5 symbols'
                    }
                }}
                {...args}
            />
            <br/>
            <ValidatedInput
                label="Only numbers"
                validationQuery={{
                    type: {
                        value: 'number',
                    }
                }}
                {...args}
            />
            <br/>
            <Typography variant="h2">
                Combined query:
            </Typography>
            <Typography variant="body1">
                The order of error messages depends on query params order. <br/>
                For this example of props: <br/>
                <div style={{ color: "green" }}>
                    {`{
                        type: {
                            value: 'number',
                            moreThen: {
                                value: 10,
                                errorMessage: 'Number should be more then 10'
                            },
                            lessThen: {
                                value: 160,
                                errorMessage: 'Number should be less then 160'
                            },
                            equal: {
                                value: 50,
                                errorMessage: 'Number should be equal 50'
                            }
                        }
                    }`}.
                </div>
                In case when we will have 3 errors at the same time - first one will be showed the error message from first prop in order -
                'moreThen' and after entering correct number, will be showed the error message from second prop in order - 'lessThen' and then 3-rd one.
            </Typography>
            <ValidatedInput
                label="Combined numbers query"
                validationQuery={{
                    type: {
                        value: 'number',
                        moreThen: {
                            value: 10,
                            errorMessage: 'Number should be more then 10'
                        },
                        lessThen: {
                            value: 160,
                            errorMessage: 'Number should be less then 160'
                        },
                        equal: {
                            value: 50,
                            errorMessage: 'Number should be equal 50'
                        }
                    }
                }}
                {...args}
            />
            <br/>
            <ValidatedInput
                label="Email"
                validationQuery={{
                    type: {
                        value: 'email',
                        errorMessage: 'Enter correct email'
                    }
                }}
                {...args}
            />
            <br/>
            <Typography variant="h2">
                Combined query:
            </Typography>
            <Typography variant="body1">
                The order of error messages depends on query params order. <br/>
                For this example of props: <br/>
                <div style={{ color: "green" }}>
                    {`{
                        minLength: {
                          value: 7,
                          errorMessage: 'Min length 7 symbols'
                        },
                        type: {
                            value: 'email',
                            errorMessage: 'Enter correct email'
                        }
                    }`}.
                </div>
                In case when we will have both errors - first one will be showed the error message from first prop in order -
                'minLength' and after entering correct length, will be showed the error message from second prop in order - 'type'.
            </Typography>
            <br/>
            <ValidatedInput
                label="Combined query"
                validationQuery={{
                    minLength: {
                      value: 7,
                      errorMessage: 'Min length 7 symbols'
                    },
                    type: {
                        value: 'email',
                        errorMessage: 'Enter correct email'
                    }
                }}
                {...args}
            />
        </div>
    )
};

export const validated_input = ValidatedInputTpl.bind({});

validated_input.args = { errorDelay: false }
